@@ -6,7 +6,7 @@ use MIDI::RtController::Filter::CC ();
 
 my $input_name  = shift || 'joystick';
 my $output_name = shift || 'usb';
-my $filter_name = shift || 'single';
+my $filter_name = shift || 'breathe';
 
 my $controller = MIDI::RtController->new(
     input   => $input_name,
@@ -16,13 +16,15 @@ my $controller = MIDI::RtController->new(
 
 my $filter = MIDI::RtController::Filter::CC->new(rtc => $controller);
 
-$filter->control(1); # CC#01 = mod-wheel
+# $controller->send_it(['patch_change', $filter->channel, 6]);
+
 # $filter->trigger(25);
+$filter->control(1); # CC#01 = mod-wheel
 # $filter->value(0);
 # $filter->range_bottom(0);
 # $filter->range_top(70);
 # $filter->range_step(2);
-# $filter->time_step(0.15);
+# $filter->time_step(60 / (60 * 24)); # seconds / (bpm * ppqn) <- for clock_it
 # $filter->step_up(10);
 # $filter->step_down(2);
 
@@ -32,3 +34,7 @@ $controller->add_filter($filter_name, all => $filter->$method);
 $controller->run;
 
 # ...and now trigger a MIDI message!
+
+END {
+    $filter->halt(1);
+}
