@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Control-change based RtController filters
 
-our $VERSION = '0.1103';
+our $VERSION = '0.1200';
 
 use v5.36;
 
@@ -108,6 +108,35 @@ sub single ($self, $device, $dt, $event) {
 }
 
 
+sub clock_it ($self, $device, $dt, $event) {
+    return 0 if $self->running;
+
+    $self->running(1);
+
+    $self->rtc->send_it(['start']);
+
+    $self->rtc->loop->add(
+        IO::Async::Timer::Periodic->new(
+            interval  => $self->time_step,
+            on_tick => sub {
+                my ($c) = @_;
+                if ($self->halt) {
+                    $self->rtc->send_it(['stop']);
+                    $c->stop;
+                    $self->running(0);
+                    $self->halt(0);
+                }
+                else {
+                    $self->rtc->send_it(['clock']);
+                }
+            },
+        )->start
+    );
+
+    return $self->continue;
+}
+
+
 sub breathe ($self, $device, $dt, $event) {
     return 0 if $self->running;
 
@@ -370,7 +399,7 @@ MIDI::RtController::Filter::CC - Control-change based RtController filters
 
 =head1 VERSION
 
-version 0.1103
+version 0.1200
 
 =head1 SYNOPSIS
 
@@ -528,6 +557,15 @@ B<channel>.
 If B<trigger> is set, the filter checks that against the MIDI event
 C<note> to see if the filter should be applied.
 
+=head2 clock_it
+
+  $control->add_filter('clock_it', all => $filter->curry::clock_it);
+
+This filter sets the B<running> flag and sends a B<clock> message,
+over the MIDI B<channel>, every iteration of B<time_step>.
+
+If the B<halt> attribute is set to true, the running filter will stop.
+
 =head2 breathe
 
   $control->add_filter('breathe', all => $filter->curry::breathe);
